@@ -1,4 +1,4 @@
-from osaft import WaveType, Yosioka1955
+from osaft import WaveType, yosioka1955
 from osaft.tests.basetest_plotting import BaseTestPlotting
 
 
@@ -19,7 +19,7 @@ class BaseTestScattering(BaseTestPlotting):
 
         self.N_max = 10
 
-        self.yosioka = Yosioka1955.ScatteringField(
+        self.yosioka = yosioka1955.ScatteringField(
             frequency=self.f,
             radius=self.R_0,
             rho_s=self.rho_s, c_s=self.c_s,
