@@ -4,7 +4,7 @@ import unittest
 import numpy as np
 from matplotlib import pyplot as plt
 
-from osaft import ARFPlot, Gorkov1962, King1934, WaveType, Yosioka1955
+from osaft import ARFPlot, WaveType, gorkov1962, king1934, yosioka1955
 from osaft.solutions.base_arf import BaseARF
 from osaft.tests.basetest_plotting import BaseTestPlotting
 
@@ -29,7 +29,7 @@ class TestARFPlot(BaseTestPlotting):
 
         out = []
         out.append(
-            King1934.ARF(
+            king1934.ARF(
                 f, R_0,
                 rho_s,
                 rho_f, c_f,
@@ -38,7 +38,7 @@ class TestARFPlot(BaseTestPlotting):
         )
 
         out.append(
-            Yosioka1955.ARF(
+            yosioka1955.ARF(
                 f, R_0,
                 rho_s, c_s,
                 rho_f, c_f,
@@ -47,7 +47,7 @@ class TestARFPlot(BaseTestPlotting):
         )
 
         out.append(
-            Gorkov1962.ARF(
+            gorkov1962.ARF(
                 f, R_0,
                 rho_s, c_s,
                 rho_f, c_f,
@@ -57,11 +57,22 @@ class TestARFPlot(BaseTestPlotting):
 
         return out
 
-    def test_warning(self) -> list[BaseARF]:
+    def test_name_error(self) -> None:
         solutions = self.create_solutions()
         for sol in solutions:
-            self.plotter.add_solution(sol)
-            self.assertRaises(ValueError, self.plotter.add_solution, sol)
+            self.plotter.add_solutions(sol)
+            self.assertRaises(ValueError, self.plotter.add_solutions, sol)
+
+    def test_error_add_zero_solutions(self) -> None:
+        self.assertRaises(TypeError, self.plotter.add_solutions)
+
+    def test_add_multiple_solutions(self):
+        solutions = self.create_solutions()
+        self.plotter.add_solutions(*solutions)
+
+        # Test if solutions are inside
+        for sol in solutions:
+            self.assertTrue(sol.name in self.plotter._solutions.keys())
 
     def test_modulo_in_linestyles(self) -> None:
         solutions = self.create_solutions()
@@ -69,7 +80,7 @@ class TestARFPlot(BaseTestPlotting):
             for sol in solutions:
                 tmp = sol
                 tmp.name = f'{tmp.name}_{i}'
-                self.plotter.add_solution(tmp)
+                self.plotter.add_solutions(tmp)
 
         self.plotter.set_abscissa(np.linspace(1e-6, 1e-5), 'R_0')
 
@@ -81,7 +92,7 @@ class TestARFPlot(BaseTestPlotting):
     def test_add_and_remove_solutions(self) -> None:
         solutions = self.create_solutions()
         for sol in solutions:
-            self.plotter.add_solution(sol)
+            self.plotter.add_solutions(sol)
         self.plotter.remove_solution(solutions[1])
 
     def test_repeated_ARF_over_R(self) -> None:
@@ -90,7 +101,7 @@ class TestARFPlot(BaseTestPlotting):
         self.plotter.set_abscissa(np.linspace(1e-6, 1e-5), 'R_0')
 
         for sol in solutions:
-            self.plotter.add_solution(sol)
+            self.plotter.add_solutions(sol)
 
         fig, ax = self.plotter.plot_solutions()
         fig, ax = self.plotter.plot_solutions()
@@ -104,7 +115,7 @@ class TestARFPlot(BaseTestPlotting):
         self.plotter.set_abscissa(np.linspace(1e-6, 1e-5, num=100), 'R_0')
 
         for sol in solutions:
-            self.plotter.add_solution(sol)
+            self.plotter.add_solutions(sol)
 
         fig, ax = self.plotter.plot_solutions()
 
@@ -117,7 +128,7 @@ class TestARFPlot(BaseTestPlotting):
         self.plotter.set_abscissa(np.linspace(1e4, 5e6, num=100), 'f')
 
         for sol in solutions:
-            self.plotter.add_solution(sol)
+            self.plotter.add_solutions(sol)
 
         fig, ax = self.plotter.plot_solutions(
             normalization_name=solutions[1].name,
@@ -132,7 +143,7 @@ class TestARFPlot(BaseTestPlotting):
         self.plotter.set_abscissa(np.linspace(1e4, 5e6, num=100), 'f')
 
         for sol in solutions:
-            self.plotter.add_solution(sol)
+            self.plotter.add_solutions(sol)
 
         fig, ax = self.plotter.plot_solutions(
             normalization_name=solutions[1].name,
@@ -148,7 +159,7 @@ class TestARFPlot(BaseTestPlotting):
         self.plotter.set_abscissa(np.linspace(1e4, 5e6, num=100), 'f')
 
         for sol in solutions:
-            self.plotter.add_solution(sol)
+            self.plotter.add_solutions(sol)
 
         fig, ax = self.plotter.plot_solutions(
             normalization_name=solutions[1].name,
@@ -158,6 +169,21 @@ class TestARFPlot(BaseTestPlotting):
         name = inspect.stack()[0][3]  # method name
         self.save_fig(fig, name)
 
+    def test_max_norm_over_f(self):
+        solutions = self.create_solutions()
+
+        self.plotter.set_abscissa(np.linspace(1e4, 5e6, num=100), 'f')
+
+        for sol in solutions:
+            self.plotter.add_solutions(sol)
+
+        fig, ax = self.plotter.plot_solutions(
+            normalization_name='max',
+        )
+
+        name = inspect.stack()[0][3]  # method name
+        self.save_fig(fig, name)
+
 
 if __name__ == '__main__':
     unittest.main()
